@@ -14,13 +14,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 import errno
 import os
 import subprocess
 import sys
 import tempfile
+from typing import Type
 
 import breezy
 from . import (
@@ -32,13 +31,6 @@ from . import (
     urlutils,
     registry,
     )
-from .sixish import (
-    PY3,
-    text_type,
-    )
-
-mail_client_registry = registry.Registry()
-
 
 class MailClientNotFound(errors.BzrError):
 
@@ -62,7 +54,7 @@ class NoMailAddressSpecified(errors.BzrError):
     _fmt = "No mail-to address (--mail-to) or output (-o) specified."
 
 
-class MailClient(object):
+class MailClient:
     """A mail client that can send messages with attachements."""
 
     def __init__(self, config):
@@ -116,6 +108,9 @@ class MailClient(object):
         return ''
 
 
+mail_client_registry = registry.Registry[str, Type[MailClient]]()
+
+
 class Editor(MailClient):
     __doc__ = """DIY mail client that uses commit message editor"""
 
@@ -123,10 +118,10 @@ class Editor(MailClient):
 
     def _get_merge_prompt(self, prompt, to, subject, attachment):
         """See MailClient._get_merge_prompt"""
-        return (u"%s\n\n"
-                u"To: %s\n"
-                u"Subject: %s\n\n"
-                u"%s" % (prompt, to, subject,
+        return ("%s\n\n"
+                "To: %s\n"
+                "Subject: %s\n\n"
+                "%s" % (prompt, to, subject,
                          attachment.decode('utf-8', 'replace')))
 
     def compose(self, prompt, to, subject, attachment, mime_subtype,
@@ -170,7 +165,7 @@ class BodyExternalMailClient(MailClient):
         """
         if basename is None:
             basename = 'attachment'
-        pathname = osutils.mkdtemp(prefix='bzr-mail-')
+        pathname = tempfile.mkdtemp(prefix='bzr-mail-')
         attach_path = osutils.pathjoin(pathname, basename + extension)
         with open(attach_path, 'wb') as outfile:
             outfile.write(attachment)
@@ -235,8 +230,6 @@ class BodyExternalMailClient(MailClient):
         :param  u:  possible unicode string.
         :return:    encoded string if u is unicode, u itself otherwise.
         """
-        if not PY3 and isinstance(u, text_type):
-            return u.encode(osutils.get_user_encoding(), 'replace')
         return u
 
     def _encode_path(self, path, kind):
@@ -248,11 +241,6 @@ class BodyExternalMailClient(MailClient):
                         path itself otherwise.
         :raise:         UnableEncodePath.
         """
-        if not PY3 and isinstance(path, text_type):
-            try:
-                return path.encode(osutils.get_user_encoding())
-            except UnicodeEncodeError:
-                raise errors.UnableEncodePath(path, kind)
         return path
 
 
@@ -276,9 +264,9 @@ class Evolution(BodyExternalMailClient):
             message_options['attach'] = attach_path
         if body is not None:
             message_options['body'] = body
-        options_list = ['%s=%s' % (k, urlutils.escape(v)) for (k, v) in
+        options_list = ['{}={}'.format(k, urlutils.escape(v)) for (k, v) in
                         sorted(message_options.items())]
-        return ['mailto:%s?%s' % (self._encode_safe(to or ''),
+        return ['mailto:{}?{}'.format(self._encode_safe(to or ''),
                                   '&'.join(options_list))]
 
 
@@ -347,7 +335,7 @@ class Thunderbird(BodyExternalMailClient):
                             urlutils.quote(self._encode_safe(body))]
         else:
             options_list = []
-        options_list.extend(["%s='%s'" % (k, v) for k, v in
+        options_list.extend(["{}='{}'".format(k, v) for k, v in
                              sorted(message_options.items())])
         return ['-compose', ','.join(options_list)]
 
@@ -402,7 +390,7 @@ class Claws(ExternalMailClient):
         # to must be supplied for the claws-mail --compose syntax to work.
         if to is None:
             raise NoMailAddressSpecified()
-        compose_url = 'mailto:%s?%s' % (
+        compose_url = 'mailto:{}?{}'.format(
             self._encode_safe(to), '&'.join(compose_url))
         # Collect command-line options.
         message_options = ['--compose', compose_url]
@@ -416,7 +404,7 @@ class Claws(ExternalMailClient):
         """See ExternalMailClient._compose"""
         if from_ is None:
             from_ = self.config.get('email')
-        super(Claws, self)._compose(prompt, to, subject, attach_path,
+        super()._compose(prompt, to, subject, attach_path,
                                     mime_subtype, extension, body, from_)
 
 
@@ -465,7 +453,7 @@ class EmacsMail(ExternalMailClient):
     _client_commands = ['emacsclient']
 
     def __init__(self, config):
-        super(EmacsMail, self).__init__(config)
+        super().__init__(config)
         self.elisp_tmp_file = None
 
     def _prepare_send_function(self):
@@ -537,7 +525,7 @@ class EmacsMail(ExternalMailClient):
         # This will work with any mail mode including default mail-mode
         # User must tweak mail-user-agent variable to tell what function
         # will be called inside compose-mail.
-        mail_cmd = "(compose-mail %s %s)" % (_to, _subject)
+        mail_cmd = "(compose-mail {} {})".format(_to, _subject)
         commandline.append(mail_cmd)
 
         # Try to attach a MIME attachment using our wrapper function
@@ -679,9 +667,9 @@ class DefaultMail(MailClient):
                 to, subject, directive, basename=basename, body=body)
 
 
-mail_client_registry.register(u'default', DefaultMail,
+mail_client_registry.register('default', DefaultMail,
                               help=DefaultMail.__doc__)
-mail_client_registry.default_key = u'default'
+mail_client_registry.default_key = 'default'
 
 opt_mail_client = _mod_config.RegistryOption(
     'mail_client', mail_client_registry, help='E-mail client to use.',
